@@ -13,6 +13,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
+
 package v1
 
 import (
@@ -192,6 +193,12 @@ func TestRevisionIsReady(t *testing.T) {
 			if got, want := r.IsReady(), tc.isReady; got != want {
 				t.Errorf("isReady =  %v want: %v", got, want)
 			}
+
+			r.Generation = 1
+			r.Status.ObservedGeneration = 2
+			if r.IsReady() {
+				t.Error("Expected IsReady() to be false when Generation != ObservedGeneration")
+			}
 		})
 	}
 }
@@ -310,7 +317,7 @@ func TestTypicalFlowWithContainerMissing(t *testing.T) {
 	apistest.CheckConditionOngoing(r, RevisionConditionContainerHealthy, t)
 	apistest.CheckConditionOngoing(r, RevisionConditionReady, t)
 
-	const want = "something about the container being not found"
+	const want = "something about the container being not found %s"
 	r.MarkContainerHealthyFalse(ReasonContainerMissing, want)
 	apistest.CheckConditionOngoing(r, RevisionConditionResourcesAvailable, t)
 	apistest.CheckConditionFailed(r, RevisionConditionContainerHealthy, t)
@@ -533,6 +540,9 @@ func TestPropagateAutoscalerStatus(t *testing.T) {
 			Conditions: duckv1.Conditions{{
 				Type:   av1alpha1.PodAutoscalerConditionReady,
 				Status: corev1.ConditionTrue,
+			}, {
+				Type:   av1alpha1.PodAutoscalerConditionScaleTargetInitialized,
+				Status: corev1.ConditionTrue,
 			}},
 		},
 	})
@@ -545,6 +555,9 @@ func TestPropagateAutoscalerStatus(t *testing.T) {
 			Conditions: duckv1.Conditions{{
 				Type:   av1alpha1.PodAutoscalerConditionReady,
 				Status: corev1.ConditionUnknown,
+			}, {
+				Type:   av1alpha1.PodAutoscalerConditionScaleTargetInitialized,
+				Status: corev1.ConditionTrue,
 			}},
 		},
 	})
@@ -557,6 +570,9 @@ func TestPropagateAutoscalerStatus(t *testing.T) {
 			Conditions: duckv1.Conditions{{
 				Type:   av1alpha1.PodAutoscalerConditionReady,
 				Status: corev1.ConditionFalse,
+			}, {
+				Type:   av1alpha1.PodAutoscalerConditionScaleTargetInitialized,
+				Status: corev1.ConditionTrue,
 			}},
 		},
 	})
@@ -565,3 +581,106 @@ func TestPropagateAutoscalerStatus(t *testing.T) {
 	apistest.CheckConditionSucceeded(r, RevisionConditionContainerHealthy, t)
 	apistest.CheckConditionSucceeded(r, RevisionConditionResourcesAvailable, t)
 }
+
+func TestPAResAvailableNoOverride(t *testing.T) {
+	r := &RevisionStatus{}
+	r.InitializeConditions()
+	apistest.CheckConditionOngoing(r, RevisionConditionReady, t)
+
+	// Deployment determined that something's wrong, e.g. the only pod
+	// has crashed.
+	r.MarkResourcesAvailableFalse("somehow", "somewhere")
+
+	// PodAutoscaler achieved initial scale.
+	r.PropagateAutoscalerStatus(&av1alpha1.PodAutoscalerStatus{
+		Status: duckv1.Status{
+			Conditions: duckv1.Conditions{{
+				Type:   av1alpha1.PodAutoscalerConditionReady,
+				Status: corev1.ConditionUnknown,
+			}, {
+				Type:   av1alpha1.PodAutoscalerConditionScaleTargetInitialized,
+				Status: corev1.ConditionTrue,
+			}},
+		},
+	})
+	// Verify we did not override this.
+	apistest.CheckConditionFailed(r, RevisionConditionResourcesAvailable, t)
+	cond := r.GetCondition(RevisionConditionResourcesAvailable)
+	if got, notWant := cond.Reason, ReasonProgressDeadlineExceeded; got == notWant {
+		t.Error("PA Status propagation overrode the ResourcesAvailable status")
+	}
+}
+
+func TestPropagateAutoscalerStatusNoProgress(t *testing.T) {
+	r := &RevisionStatus{}
+	r.InitializeConditions()
+	apistest.CheckConditionOngoing(r, RevisionConditionReady, t)
+
+	// PodAutoscaler is not ready and initial scale was never attained.
+	r.PropagateAutoscalerStatus(&av1alpha1.PodAutoscalerStatus{
+		ServiceName: "testRevision",
+		Status: duckv1.Status{
+			Conditions: duckv1.Conditions{{
+				Type:   av1alpha1.PodAutoscalerConditionReady,
+				Status: corev1.ConditionFalse,
+			}, {
+				Type:   av1alpha1.PodAutoscalerConditionScaleTargetInitialized,
+				Status: corev1.ConditionUnknown,
+			}},
+		},
+	})
+	apistest.CheckConditionFailed(r, RevisionConditionActive, t)
+	apistest.CheckConditionFailed(r, RevisionConditionResourcesAvailable, t)
+	cond := r.GetCondition(RevisionConditionResourcesAvailable)
+	if got, want := cond.Reason, ReasonProgressDeadlineExceeded; got != want {
+		t.Errorf("Reason = %q, want: %q", got, want)
+	}
+
+	// Set a different reason/message
+	r.MarkResourcesAvailableFalse("another-one", "bit-the-dust")
+
+	// And apply the status.
+	r.PropagateAutoscalerStatus(&av1alpha1.PodAutoscalerStatus{
+		Status: duckv1.Status{
+			Conditions: duckv1.Conditions{{
+				Type:   av1alpha1.PodAutoscalerConditionReady,
+				Status: corev1.ConditionFalse,
+			}, {
+				Type:   av1alpha1.PodAutoscalerConditionScaleTargetInitialized,
+				Status: corev1.ConditionUnknown,
+			}},
+		},
+	})
+	// Verify it did not alter the reason/message.
+	cond = r.GetCondition(RevisionConditionResourcesAvailable)
+	if got, want := cond.Reason, ReasonProgressDeadlineExceeded; got == want {
+		t.Errorf("Reason = %q should have not overridden a different status", got)
+	}
+}
+
+func TestPropagateAutoscalerStatusRace(t *testing.T) {
+	r := &RevisionStatus{}
+	r.InitializeConditions()
+	apistest.CheckConditionOngoing(r, RevisionConditionReady, t)
+
+	// PodAutoscaler has no active condition, so we are just coming up.
+	r.PropagateAutoscalerStatus(&av1alpha1.PodAutoscalerStatus{
+		Status: duckv1.Status{},
+	})
+	apistest.CheckConditionOngoing(r, RevisionConditionActive, t)
+
+	// The PodAutoscaler might have been ready but it's scaled down already.
+	r.PropagateAutoscalerStatus(&av1alpha1.PodAutoscalerStatus{
+		Status: duckv1.Status{
+			Conditions: duckv1.Conditions{{
+				Type:   av1alpha1.PodAutoscalerConditionReady,
+				Status: corev1.ConditionFalse,
+			}, {
+				Type:   av1alpha1.PodAutoscalerConditionScaleTargetInitialized,
+				Status: corev1.ConditionTrue,
+			}},
+		},
+	})
+	apistest.CheckConditionFailed(r, RevisionConditionActive, t)
+	apistest.CheckConditionSucceeded(r, RevisionConditionReady, t)
+}
