@@ -23,6 +23,7 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	network "knative.dev/networking/pkg"
 	"knative.dev/pkg/apis"
 	"knative.dev/pkg/ptr"
 	"knative.dev/serving/pkg/apis/serving"
@@ -40,8 +41,7 @@ func TestTrafficTargetValidation(t *testing.T) {
 			RevisionName: "bar",
 			Percent:      ptr.Int64(12),
 		},
-		wc:   apis.WithinSpec,
-		want: nil,
+		wc: apis.WithinSpec,
 	}, {
 		name: "valid with revisionName and name (spec)",
 		tt: &TrafficTarget{
@@ -49,8 +49,7 @@ func TestTrafficTargetValidation(t *testing.T) {
 			RevisionName: "bar",
 			Percent:      ptr.Int64(12),
 		},
-		wc:   apis.WithinSpec,
-		want: nil,
+		wc: apis.WithinSpec,
 	}, {
 		name: "valid with revisionName and name (status)",
 		tt: &TrafficTarget{
@@ -62,8 +61,7 @@ func TestTrafficTargetValidation(t *testing.T) {
 				Host:   "foo.bar.com",
 			},
 		},
-		wc:   apis.WithinStatus,
-		want: nil,
+		wc: apis.WithinStatus,
 	}, {
 		name: "invalid with revisionName and name (status)",
 		tt: &TrafficTarget{
@@ -89,8 +87,7 @@ func TestTrafficTargetValidation(t *testing.T) {
 			LatestRevision: ptr.Bool(false),
 			Percent:        ptr.Int64(12),
 		},
-		wc:   apis.WithinSpec,
-		want: nil,
+		wc: apis.WithinSpec,
 	}, {
 		name: "invalid with revisionName and latestRevision (spec)",
 		tt: &TrafficTarget{
@@ -107,16 +104,14 @@ func TestTrafficTargetValidation(t *testing.T) {
 			LatestRevision: ptr.Bool(true),
 			Percent:        ptr.Int64(12),
 		},
-		wc:   apis.WithinStatus,
-		want: nil,
+		wc: apis.WithinStatus,
 	}, {
 		name: "valid with configurationName",
 		tt: &TrafficTarget{
 			ConfigurationName: "bar",
 			Percent:           ptr.Int64(37),
 		},
-		wc:   apis.WithinSpec,
-		want: nil,
+		wc: apis.WithinSpec,
 	}, {
 		name: "valid with configurationName and name (spec)",
 		tt: &TrafficTarget{
@@ -124,8 +119,7 @@ func TestTrafficTargetValidation(t *testing.T) {
 			ConfigurationName: "bar",
 			Percent:           ptr.Int64(37),
 		},
-		wc:   apis.WithinSpec,
-		want: nil,
+		wc: apis.WithinSpec,
 	}, {
 		name: "invalid with bad configurationName",
 		tt: &TrafficTarget{
@@ -142,8 +136,7 @@ func TestTrafficTargetValidation(t *testing.T) {
 			LatestRevision:    ptr.Bool(true),
 			Percent:           ptr.Int64(37),
 		},
-		wc:   apis.WithinSpec,
-		want: nil,
+		wc: apis.WithinSpec,
 	}, {
 		name: "invalid with configurationName and latestRevision",
 		tt: &TrafficTarget{
@@ -169,7 +162,6 @@ func TestTrafficTargetValidation(t *testing.T) {
 		wc: func(ctx context.Context) context.Context {
 			return WithDefaultConfigurationName(apis.WithinSpec(ctx))
 		},
-		want: nil,
 	}, {
 		name: "valid with default configurationName and latestRevision",
 		tt: &TrafficTarget{
@@ -179,7 +171,6 @@ func TestTrafficTargetValidation(t *testing.T) {
 		wc: func(ctx context.Context) context.Context {
 			return WithDefaultConfigurationName(apis.WithinSpec(ctx))
 		},
-		want: nil,
 	}, {
 		name: "invalid with default configurationName and latestRevision",
 		tt: &TrafficTarget{
@@ -190,49 +181,36 @@ func TestTrafficTargetValidation(t *testing.T) {
 			return WithDefaultConfigurationName(apis.WithinSpec(ctx))
 		},
 		want: apis.ErrGeneric(`may not set revisionName "" when latestRevision is false`, "latestRevision"),
-	}, {
-		name: "invalid without revisionName in status",
-		tt: &TrafficTarget{
-			ConfigurationName: "blah",
-			Percent:           ptr.Int64(37),
-		},
-		wc:   apis.WithinStatus,
-		want: apis.ErrMissingField("revisionName"),
 	}, {
 		name: "valid with revisionName and default configurationName",
 		tt: &TrafficTarget{
 			RevisionName: "bar",
 			Percent:      ptr.Int64(12),
 		},
-		wc:   WithDefaultConfigurationName,
-		want: nil,
+		wc: WithDefaultConfigurationName,
 	}, {
 		name: "valid with no percent",
 		tt: &TrafficTarget{
 			ConfigurationName: "booga",
 		},
-		want: nil,
 	}, {
 		name: "valid with nil percent",
 		tt: &TrafficTarget{
 			ConfigurationName: "booga",
 			Percent:           nil,
 		},
-		want: nil,
 	}, {
 		name: "valid with zero percent",
 		tt: &TrafficTarget{
 			ConfigurationName: "booga",
 			Percent:           ptr.Int64(0),
 		},
-		want: nil,
 	}, {
 		name: "valid with no name",
 		tt: &TrafficTarget{
 			ConfigurationName: "booga",
 			Percent:           ptr.Int64(100),
 		},
-		want: nil,
 	}, {
 		name: "invalid with both",
 		tt: &TrafficTarget{
@@ -326,7 +304,6 @@ func TestRouteValidation(t *testing.T) {
 				},
 			},
 		},
-		want: nil,
 	}, {
 		name: "valid split",
 		r: &Route{
@@ -345,7 +322,6 @@ func TestRouteValidation(t *testing.T) {
 				}},
 			},
 		},
-		want: nil,
 	}, {
 		name: "valid split without tags",
 		r: &Route{
@@ -362,36 +338,6 @@ func TestRouteValidation(t *testing.T) {
 				}},
 			},
 		},
-		want: nil,
-	}, {
-		name: "missing url in status",
-		r: &Route{
-			ObjectMeta: metav1.ObjectMeta{
-				Name: "valid",
-			},
-			Spec: RouteSpec{
-				Traffic: []TrafficTarget{{
-					Tag:          "bar",
-					RevisionName: "foo",
-					Percent:      ptr.Int64(100),
-				}},
-			},
-			Status: RouteStatus{
-				RouteStatusFields: RouteStatusFields{
-					Traffic: []TrafficTarget{{
-						Tag:          "bar",
-						RevisionName: "foo",
-						Percent:      ptr.Int64(100),
-					}},
-				},
-			},
-		},
-		want: &apis.FieldError{
-			Message: "missing field(s)",
-			Paths: []string{
-				"status.traffic[0].url",
-			},
-		},
 	}, {
 		name: "invalid traffic entry (missing oneof)",
 		r: &Route{
@@ -539,24 +485,23 @@ func TestRouteLabelValidation(t *testing.T) {
 			ObjectMeta: metav1.ObjectMeta{
 				Name: "byo-name",
 				Labels: map[string]string{
-					serving.VisibilityLabelKey: "cluster-local",
+					network.VisibilityLabelKey: "cluster-local",
 				},
 			},
 			Spec: validRouteSpec,
 		},
-		want: nil,
 	}, {
 		name: "invalid visibility name",
 		r: &Route{
 			ObjectMeta: metav1.ObjectMeta{
 				Name: "byo-name",
 				Labels: map[string]string{
-					serving.VisibilityLabelKey: "bad-value",
+					network.VisibilityLabelKey: "bad-value",
 				},
 			},
 			Spec: validRouteSpec,
 		},
-		want: apis.ErrInvalidValue("bad-value", "metadata.labels.serving.knative.dev/visibility"),
+		want: apis.ErrInvalidValue("bad-value", "metadata.labels."+network.VisibilityLabelKey),
 	}, {
 		name: "valid knative service name",
 		r: &Route{
@@ -573,7 +518,6 @@ func TestRouteLabelValidation(t *testing.T) {
 			},
 			Spec: validRouteSpec,
 		},
-		want: nil,
 	}, {
 		name: "invalid knative service name",
 		r: &Route{
@@ -641,7 +585,9 @@ func TestRouteLabelValidation(t *testing.T) {
 			Spec: validRouteSpec,
 		},
 	}, {
-		name: "invalid knative label",
+		// We want to be able to introduce new labels with the serving prefix in the future
+		// and not break downgrading.
+		name: "allow unknown uses of knative.dev/serving prefix",
 		r: &Route{
 			ObjectMeta: metav1.ObjectMeta{
 				Name: "byo-name",
@@ -651,7 +597,7 @@ func TestRouteLabelValidation(t *testing.T) {
 			},
 			Spec: validRouteSpec,
 		},
-		want: apis.ErrInvalidKeyName("serving.knative.dev/testlabel", "metadata.labels"),
+		want: nil,
 	}}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
@@ -681,10 +627,10 @@ func TestRouteAnnotationUpdate(t *testing.T) {
 		u3 = "vaca@knative.dev"
 	)
 	tests := []struct {
-		name string
-		prev *Route
-		this *Route
-		want *apis.FieldError
+		name    string
+		prev    *Route
+		this    *Route
+		wantErr *apis.FieldError
 	}{{
 		name: "update creator annotation",
 		this: &Route{
@@ -707,7 +653,7 @@ func TestRouteAnnotationUpdate(t *testing.T) {
 			},
 			Spec: getRouteSpec("old"),
 		},
-		want: (&apis.FieldError{Message: "annotation value is immutable",
+		wantErr: (&apis.FieldError{Message: "annotation value is immutable",
 			Paths: []string{serving.CreatorAnnotation}}).ViaField("metadata.annotations"),
 	}, {
 		name: "update creator annotation with spec changes",
@@ -731,7 +677,7 @@ func TestRouteAnnotationUpdate(t *testing.T) {
 			},
 			Spec: getRouteSpec("old"),
 		},
-		want: (&apis.FieldError{Message: "annotation value is immutable",
+		wantErr: (&apis.FieldError{Message: "annotation value is immutable",
 			Paths: []string{serving.CreatorAnnotation}}).ViaField("metadata.annotations"),
 	}, {
 		name: "update lastModifier annotation without spec changes",
@@ -755,7 +701,7 @@ func TestRouteAnnotationUpdate(t *testing.T) {
 			},
 			Spec: getRouteSpec("old"),
 		},
-		want: apis.ErrInvalidValue(u2, serving.UpdaterAnnotation).ViaField("metadata.annotations"),
+		wantErr: apis.ErrInvalidValue(u2, serving.UpdaterAnnotation).ViaField("metadata.annotations"),
 	}, {
 		name: "update lastModifier annotation with spec changes",
 		this: &Route{
@@ -778,7 +724,29 @@ func TestRouteAnnotationUpdate(t *testing.T) {
 			},
 			Spec: getRouteSpec("old"),
 		},
-		want: nil,
+	}, {
+		name: "rollout duration validation",
+		this: &Route{
+			ObjectMeta: metav1.ObjectMeta{
+				Name: "valid",
+				Annotations: map[string]string{
+					serving.RolloutDurationKey: "123s",
+				},
+			},
+			Spec: getRouteSpec("new"),
+		},
+	}, {
+		name: "rollout duration validation, fail",
+		this: &Route{
+			ObjectMeta: metav1.ObjectMeta{
+				Name: "valid",
+				Annotations: map[string]string{
+					serving.RolloutDurationKey: "three hours and seventeen seconds",
+				},
+			},
+			Spec: getRouteSpec("new"),
+		},
+		wantErr: apis.ErrInvalidValue("three hours and seventeen seconds", serving.RolloutDurationKey).ViaField("metadata.annotations"),
 	}, {
 		name: "no validation for lastModifier annotation even after update without spec changes as route owned by service",
 		this: &Route{
@@ -805,7 +773,6 @@ func TestRouteAnnotationUpdate(t *testing.T) {
 			},
 			Spec: getRouteSpec("old"),
 		},
-		want: nil,
 	}, {
 		name: "no validation for creator annotation even after update as route owned by service",
 		this: &Route{
@@ -832,14 +799,15 @@ func TestRouteAnnotationUpdate(t *testing.T) {
 			},
 			Spec: getRouteSpec("old"),
 		},
-		want: nil,
 	}}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
 			ctx := context.Background()
-			ctx = apis.WithinUpdate(ctx, test.prev)
-			if diff := cmp.Diff(test.want.Error(), test.this.Validate(ctx).Error()); diff != "" {
-				t.Errorf("Validate (-want, +got) = %v", diff)
+			if test.prev != nil {
+				ctx = apis.WithinUpdate(ctx, test.prev)
+			}
+			if diff := cmp.Diff(test.wantErr.Error(), test.this.Validate(ctx).Error()); diff != "" {
+				t.Error("Validate (-want, +got) =", diff)
 			}
 		})
 	}
